/*

  ESP32_receiver.ino - ESP-NOW ESP32 Arduino Sketch for Receiver Side

  An example project borrowed from the tutorial: 
  ESP32 ESP-NOW Getting Started Tutorial with Arduino IDE
  Link: https://microcontrollerslab.com/esp32-esp-now-tutorial-arduino-ide/

  ESP-NOW One-way Communication
  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  Now, let us learn how to send data from one ESP32 board to another, 
  using the ESP-NOW protocol. We will use the simplest configuration, 
  where one ESP32 board acts as the sender and the other ESP32 board 
  acts as the receiver. 

  You can use the method given below to transmit sensor data or any type 
  of information from one ESP board to another. We will keep it simple 
  and create a structure in our sketch which will store values of type 
  char, int, float, and Boolean. This will help us in transmitting any 
  type of data by just changing the structure in the sketch. For this 
  project, we will require two Arduino sketches one for the sender and 
  the other for the receiver.

*/


#include <esp_now.h>
#include <WiFi.h>

typedef struct struct_message {
    char character[100];
    int integer;
    float floating_value;
    bool bool_value;
} struct_message;


struct_message message;

void data_receive(const uint8_t * mac, const uint8_t *incomingData, int len) {
  memcpy(&message, incomingData, sizeof(message));
  Serial.print("Bytes received: ");
  Serial.println(len);
  Serial.print("Char: ");
  Serial.println(message.character);
  Serial.print("Int: ");
  Serial.println(message.integer);
  Serial.print("Float: ");
  Serial.println(message.floating_value);
  Serial.print("Bool: ");
  Serial.println(message.bool_value);
  Serial.println();
}
 
void setup() {
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);

  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }
  
  esp_now_register_recv_cb(data_receive);
}
 
void loop() {

}
