/*

  ESP32_sender.ino - ESP-NOW ESP32 Arduino Sketch for Sender Side

  An example project borrowed from the tutorial:
  ESP32 ESP-NOW Getting Started Tutorial with Arduino IDE
  Link: https://microcontrollerslab.com/esp32-esp-now-tutorial-arduino-ide/

  ESP-NOW One-way Communication
  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  Now, let us learn how to send data from one ESP32 board to another,
  using the ESP-NOW protocol. We will use the simplest configuration,
  where one ESP32 board acts as the sender and the other ESP32 board
  acts as the receiver.

  You can use the method given below to transmit sensor data or any type
  of information from one ESP board to another. We will keep it simple
  and create a structure in our sketch which will store values of type
  char, int, float, and Boolean. This will help us in transmitting any
  type of data by just changing the structure in the sketch. For this
  project, we will require two Arduino sketches one for the sender and
  the other for the receiver.

*/



#include <esp_now.h>
#include <WiFi.h>

// REPLACE WITH YOUR RECEIVER MAC Address
uint8_t broadcastAddress[] = {0x24, 0x62, 0xAB, 0xCA, 0x55, 0xCC};

typedef struct struct_message {
  char character[100];
  int integer;
  float floating_value;
  bool bool_value;
} struct_message;

struct_message message;
esp_now_peer_info_t peerInfo;

void data_sent(const uint8_t *mac_addr, esp_now_send_status_t status) {
  Serial.print("\r\nStatus of Last Message Sent:\t");
  Serial.println(status == ESP_NOW_SEND_SUCCESS ? "Delivery Success" : "Delivery Fail");
}

void setup() {
  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  if (esp_now_init() != ESP_OK) {
    Serial.println("Error initializing ESP-NOW");
    return;
  }
  esp_now_register_send_cb(data_sent);
  memcpy(peerInfo.peer_addr, broadcastAddress, 6);
  peerInfo.channel = 0;
  peerInfo.encrypt = false;
  if (esp_now_add_peer(&peerInfo) != ESP_OK) {
    Serial.println("Failed to add peer");
    return;
  }
}

void loop() {
  strcpy(message.character, "Welcome to Microcontrollerslab! This is test example.");
  message.integer = random(1, 10);
  message.floating_value = 5.6;
  message.bool_value = true;

  esp_err_t outcome = esp_now_send(broadcastAddress, (uint8_t *) &message, sizeof(message));

  if (outcome == ESP_OK) {
    Serial.println("Mesage sent successfully!");
  }
  else {
    Serial.println("Error sending the message");
  }
  delay(2000);
}
